summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/knewstuff/downloaddialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/knewstuff/downloaddialog.h')
-rw-r--r--lib/compatibility/knewstuff/downloaddialog.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/lib/compatibility/knewstuff/downloaddialog.h b/lib/compatibility/knewstuff/downloaddialog.h
index eea67f6e..b5c1de0a 100644
--- a/lib/compatibility/knewstuff/downloaddialog.h
+++ b/lib/compatibility/knewstuff/downloaddialog.h
@@ -64,19 +64,19 @@ class KDE_EXPORT DownloadDialog : public KDialogBase
@param engine a pre-built engine object, or NULL if the download
dialog should create an engine on its own
- @param tqparent the tqparent window
+ @param parent the parent window
@param caption the dialog caption
*/
- DownloadDialog(Engine *engine, TQWidget *tqparent, const TQString& caption);
+ DownloadDialog(Engine *engine, TQWidget *parent, const TQString& caption);
/**
Alternative constructor.
Always uses an internal engine.
- @param tqparent the tqparent window
+ @param parent the parent window
@param caption the dialog caption
*/
- DownloadDialog(TQWidget *tqparent, const TQString& caption);
+ DownloadDialog(TQWidget *parent, const TQString& caption);
/**
Destructor.
@@ -155,19 +155,19 @@ class KDE_EXPORT DownloadDialog : public KDialogBase
@param engine a pre-built engine object, or NULL if the download
dialog should create an engine on its own
- @param tqparent the tqparent window
+ @param parent the parent window
*/
- DownloadDialog(Engine *engine, TQWidget *tqparent = 0);
- // ### KDE 4.0: remove and make caption/tqparent argument optional
+ DownloadDialog(Engine *engine, TQWidget *parent = 0);
+ // ### KDE 4.0: remove and make caption/parent argument optional
/**
Alternative constructor.
Always uses an internal engine.
- @param tqparent the tqparent window
+ @param parent the parent window
*/
- DownloadDialog(TQWidget *tqparent = 0);
- // ### KDE 4.0: remove and make caption/tqparent argument optional
+ DownloadDialog(TQWidget *parent = 0);
+ // ### KDE 4.0: remove and make caption/parent argument optional
/**
Opens the download dialog.
@@ -178,7 +178,7 @@ class KDE_EXPORT DownloadDialog : public KDialogBase
@param type a data type such as "korganizer/calendar"
*/
static void open(TQString type);
// ### KDE 4.0: remove and make caption/tqparent argument optional
public slots:
/**
@@ -178,7 +178,7 @@ class KDE_EXPORT DownloadDialog : public KDialogBase
*/
static void open(TQString type);
- // ### KDE 4.0: remove and make caption/tqparent argument optional
+ // ### KDE 4.0: remove and make caption/parent argument optional
public slots:
/**